@@ -15,7 +15,7 @@ except ImportError:
     pass
 
 # internal cache for setting values
-_cache = dict()
+_cache = {}
 
 
 def set_value(key, value):
@@ -39,3 +39,10 @@ def get_value(key):
             value = _cache[key]
 
     return value
+
+
+def clear_cache():
+    if UWSGI:
+        uwsgi.cache_clear()
+    else:
+        _cache.clear()
\ No newline at end of file
